==> org.EcSakai.eg.db_2.2.11.tar.gz: org.EcSakai.eg.db/man/org.EcSakai.eg_dbconn.Rd <==
\name{org.EcSakai.eg_dbconn}

\alias{org.EcSakai.eg_dbconn}
\alias{org.EcSakai.eg_dbfile}
\alias{org.EcSakai.eg_dbschema}
\alias{org.EcSakai.eg_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  org.EcSakai.eg_dbconn()
  org.EcSakai.eg_dbfile()
  org.EcSakai.eg_dbschema(file="", show.indices=FALSE)
  org.EcSakai.eg_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{org.EcSakai.eg_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{org.EcSakai.eg_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{org.EcSakai.eg_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{org.EcSakai.eg_dbschema} prints the schema definition of the
  package annotation DB.

  \code{org.EcSakai.eg_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{org.EcSakai.eg_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{org.EcSakai.eg_dbfile}: a character string with the path to the
  package annotation DB.

  \code{org.EcSakai.eg_dbschema}: none (invisible \code{NULL}).

  \code{org.EcSakai.eg_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "genes" table:
  dbGetQuery(org.EcSakai.eg_dbconn(), "SELECT COUNT(*) FROM genes")

  ## The connection object returned by org.EcSakai.eg_dbconn() was created with:
  dbConnect(SQLite(), dbname=org.EcSakai.eg_dbfile(), cache_size=64000, synchronous=0)

  org.EcSakai.eg_dbschema()

  org.EcSakai.eg_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> org.EcSakai.eg.db_2.4.1.tar.gz: org.EcSakai.eg.db/man/org.EcSakai.eg_dbconn.Rd <==

\name{org.EcSakai.eg_dbconn}

\alias{org.EcSakai.eg_dbconn}
\alias{org.EcSakai.eg_dbfile}
\alias{org.EcSakai.eg_dbschema}
\alias{org.EcSakai.eg_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  org.EcSakai.eg_dbconn()
  org.EcSakai.eg_dbfile()
  org.EcSakai.eg_dbschema(file="", show.indices=FALSE)
  org.EcSakai.eg_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{org.EcSakai.eg_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{org.EcSakai.eg_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{org.EcSakai.eg_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{org.EcSakai.eg_dbschema} prints the schema definition of the
  package annotation DB.

  \code{org.EcSakai.eg_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{org.EcSakai.eg_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{org.EcSakai.eg_dbfile}: a character string with the path to the
  package annotation DB.

  \code{org.EcSakai.eg_dbschema}: none (invisible \code{NULL}).

  \code{org.EcSakai.eg_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "genes" table:
  dbGetQuery(org.EcSakai.eg_dbconn(), "SELECT COUNT(*) FROM genes")

  ## The connection object returned by org.EcSakai.eg_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=org.EcSakai.eg_dbfile(), cache_size=64000,
  synchronous=0)

  org.EcSakai.eg_dbschema()

  org.EcSakai.eg_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
